@@ -1,6 +1,7 @@
 import uuid
 
 from socketio import packet
+from socketio.pubsub_manager import PubSubManager
 from werkzeug.test import EnvironBuilder
 
 
@@ -38,16 +39,21 @@ class SocketIOTestClient(object):
 
         self.app = app
         self.sid = uuid.uuid4().hex
+        self.queue[self.sid] = []
         self.callback_counter = 0
         self.socketio = socketio
         socketio.server._send_packet = _mock_send_packet
         socketio.server.environ[self.sid] = {}
+        if isinstance(socketio.server.manager, PubSubManager):
+            raise RuntimeError('Test client cannot be used with a message '
+                               'queue. Disable the queue on your test '
+                               'configuration.')
         socketio.server.manager.initialize(socketio.server)
         self.connect(namespace)
 
     def connect(self, namespace=None):
         """Connect the client.
-        
+
         :param namespace: The namespace for the client. If not provided, the
                           client connects to the server on the global
                           namespace.
@@ -68,7 +74,7 @@ class SocketIOTestClient(object):
 
     def disconnect(self, namespace=None):
         """Disconnect the client.
-        
+
         :param namespace: The namespace to disconnect. The global namespace is
                          assumed if this argument is not provided.
         """
@@ -78,12 +84,12 @@ class SocketIOTestClient(object):
 
     def emit(self, event, *args, **kwargs):
         """Emit an event to the server.
-        
+
         :param event: The event name.
         :param *args: The event arguments.
         :param callback: ``True`` if the client requests a callback, ``False``
                          if not. Note that client-side callbacks are not
-                         implemented, a callback request will just tell the 
+                         implemented, a callback request will just tell the
                          server to provide the arguments to invoke the
                          callback, but no callback is invoked. Instead, the
                          arguments that the server provided for the callback
@@ -114,7 +120,7 @@ class SocketIOTestClient(object):
                      message.
         :param callback: ``True`` if the client requests a callback, ``False``
                          if not. Note that client-side callbacks are not
-                         implemented, a callback request will just tell the 
+                         implemented, a callback request will just tell the
                          server to provide the arguments to invoke the
                          callback, but no callback is invoked. Instead, the
                          arguments that the server provided for the callback
